#ifndef NT2_INCLUDE_FUNCTIONS_REVERSEBITS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_REVERSEBITS_HPP_INCLUDED

#include <nt2/bitwise/include/functions/reversebits.hpp>

#endif
